# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroup import ConsistencyGroup  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember import ConsistencyGroupMember  # noqa: F401,E501

class ConsistencyGroupProjection(ConsistencyGroup):

    """

    :param name: (:attr:`name`) Name of the Consistency group.
    :type name: required
    :param owner_ext_id: (:attr:`owner_ext_id`) The external identifier of the user who created this Consistency group. This is a read-only field that is inserted into the Consistency group entity at the time of Consistency group creation.
    :type owner_ext_id: 
    :param members: (:attr:`members`) 
    :type members: 
    :param ext_id: (:attr:`ext_id`) A globally unique identifier of an instance that is suitable for external consumption. 
    :type ext_id: 
    :param links: (:attr:`links`) A HATEOAS style link for the response.  Each link contains a user friendly name identifying the link and an address for retrieving the particular resource. 
    :type links: 
    :param tenant_id: (:attr:`tenant_id`) A globally unique identifier that represents the tenant that owns this entity.  It is automatically assigned by the system and is immutable from an API consumer perspective (some use cases may cause this Id to change - for instance a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server). 
    :type tenant_id: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'owner_ext_id': 'str',
        'members': 'list[dataprotection.v4.config.ConsistencyGroupMember]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'owner_ext_id': 'ownerExtId',
        'members': 'members',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, owner_ext_id=None, members=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ConsistencyGroup.__init__(self, name, owner_ext_id, members, ext_id, links, tenant_id, *args, **kwargs)
        self.discriminator = None

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.ConsistencyGroupProjection'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.ConsistencyGroupProjection'


    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ConsistencyGroupProjection, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConsistencyGroupProjection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.common.v1.config.TenantAwareModel import TenantAwareModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501

class ExternalizableAbstractModel(TenantAwareModel):

    """A model that represents an object instance that is accessible through an API endpoint.  Instances of this type get an extId field that contains the globally unique identifier for that instance.  Externally accessible instances are always tenant aware and therefore extend the TenantAwareModel 

    :param ext_id: (:attr:`ext_id`) A globally unique identifier of an instance that is suitable for external consumption. 
    :type ext_id: 
    :param links: (:attr:`links`) A HATEOAS style link for the response.  Each link contains a user friendly name identifying the link and an address for retrieving the particular resource. 
    :type links: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        TenantAwareModel.__init__(self, tenant_id, *args, **kwargs)
        self.__ext_id = None
        self.__links = None
        self.discriminator = None
        if ext_id is not None:
            self.__ext_id = ext_id
        if links is not None:
            self.__links = links

    def _initialize_object_type(self):
        return 'common.v1.response.ExternalizableAbstractModel'

    def _initialize_fq_object_type(self):
        return 'common.v1.r0.a3.response.ExternalizableAbstractModel'


    @property
    def ext_id(self):
        """
        A globally unique identifier of an instance that is suitable for external consumption. 

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__ext_id

    @ext_id.setter
    def ext_id(self, ext_id):
        if ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__ext_id = ext_id

    @property
    def links(self):
        """
        A HATEOAS style link for the response.  Each link contains a user friendly name identifying the link and an address for retrieving the particular resource. 

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.common.v1.response.ApiLink` ]
        """  # noqa: E501
        return self.__links

    @links.setter
    def links(self, links):

        self.__links = links

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ExternalizableAbstractModel, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExternalizableAbstractModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

import io
import json
import logging
import re
import ssl

import certifi
# python 2 and python 3 compatibility library
import six
from six.moves.urllib.parse import urlencode

try:
    import urllib3
    from urllib3.contrib.socks import SOCKSProxyManager
except ImportError:
    raise ImportError('Swagger python client requires urllib3.')


logger = logging.getLogger(__name__)


class RESTResponse(io.IOBase):

    def __init__(self, resp):
        self.urllib3_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = resp.data

    def getheaders(self):
        """Returns a dictionary of the response headers."""
        return self.urllib3_response.getheaders()

    def getheader(self, name, default=None):
        """Returns a given response header."""
        return self.urllib3_response.getheader(name, default)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=None, max_retry_attempts=5, backoff_factor=3):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        self.__configuration = configuration

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if configuration.ssl_ca_cert:
            ca_certs = configuration.ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args['assert_hostname'] = configuration.assert_hostname  # noqa: E501

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # retry mechanism
        retries = urllib3.util.Retry(total=None, status=max_retry_attempts, read=0, connect=0, other=0, status_forcelist=[408, 503, 504], backoff_factor=backoff_factor, raise_on_status=False)

        # https pool manager
        if configuration.proxy_scheme and configuration.proxy_host and configuration.proxy_port:
            proxy_url = ''.join([
                configuration.proxy_scheme,
                '://',
                configuration.proxy_host,
                ':',
                str(configuration.proxy_port)
            ])
            proxy_headers = (
                urllib3.util.make_headers(
                proxy_basic_auth=configuration.proxy_username + ':' + configuration.proxy_password) if
                (configuration.proxy_username and configuration.proxy_password) else None
            )
            if configuration.proxy_scheme == "socks5":
                self.pool_manager = SOCKSProxyManager(
                    num_pools=pools_size,
                    maxsize=maxsize,
                    cert_reqs=cert_reqs,
                    ca_certs=ca_certs,
                    cert_file=configuration.cert_file,
                    key_file=configuration.key_file,
                    proxy_url=proxy_url,
                    username=configuration.proxy_username,
                    password=configuration.proxy_password,
                    retries = retries,
                    **addition_pool_args
                )
            else:
                self.pool_manager = urllib3.ProxyManager(
                    num_pools=pools_size,
                    maxsize=maxsize,
                    cert_reqs=cert_reqs,
                    ca_certs=ca_certs,
                    cert_file=configuration.cert_file,
                    key_file=configuration.key_file,
                    proxy_url=proxy_url,
                    proxy_headers=proxy_headers,
                    retries = retries,
                    **addition_pool_args
                )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                retries = retries,
                **addition_pool_args
            )

    def request(self, method, url, query_params=None, headers=None,
                body=None, post_params=None, _preload_content=True,
                _request_timeout=None):
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT',
                          'PATCH', 'OPTIONS']

        if post_params and body:
            msg = "body parameter cannot be used with post_params parameter."
            logger.error(msg)
            raise ValueError(msg)

        post_params = post_params or {}
        headers = headers or {}

        timeout = None
        if _request_timeout:
            if isinstance(_request_timeout, (int, float) if six.PY3 else (int, long, float)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=_request_timeout)
            elif (isinstance(_request_timeout, list) and len(_request_timeout) == 2):
                timeout = urllib3.Timeout(connect=_request_timeout[0], read=_request_timeout[1])

        if 'Content-Type' not in headers:
            headers['Content-Type'] = 'application/json'

        # Print log statements
        logger.info("%s %s", method, url + '?' + urlencode(query_params) if query_params else url)
        # Print debug logs, if enabled
        if self.__configuration.debug:
            logger.debug("Request Headers:")
            for key, value in six.iteritems(headers):
                logger.debug("%s: %s", key, value)

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                if query_params:
                    url += '?' + urlencode(query_params)
                if re.search('json', headers['Content-Type'], re.IGNORECASE):
                    request_body = None
                    if body is not None:
                        request_body = json.dumps(body)

                    # Print request body, if debug configuration is enabled
                    if self.__configuration.debug:
                        logger.debug("Request Body: %s", request_body)

                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
                    r = self.pool_manager.request(
                        method, url,
                        fields=post_params,
                        encode_multipart=False,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(
                        method, url,
                        fields=post_params,
                        encode_multipart=True,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str):
                    request_body = body
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              fields=query_params,
                                              preload_content=_preload_content,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)
        except Exception as e:
            logger.error(str(e))
            raise

        if _preload_content:
            r = RESTResponse(r)

            # In the python 3, the response.data is bytes.
            # we need to decode it to string.
            if six.PY3:
                r.data = r.data.decode('utf8')

        # Print log statements
        logger.info("Response Status: %s %s", r.status, r.reason)
        # Print debug logs, if enabled
        if self.__configuration.debug:
            logger.debug("Response Headers:")
            for key, value in six.iteritems(r.getheaders()):
                logger.debug("%s: %s", key, value)
            logger.debug("Response Body: %s", r.data)

        if not 200 <= r.status <= 299 and not 401 == r.status:
            raise ApiException(http_resp=r)

        return r

    def GET(self, url, headers=None, query_params=None, _preload_content=True,
            _request_timeout=None):
        return self.request("GET", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def HEAD(self, url, headers=None, query_params=None, _preload_content=True,
             _request_timeout=None):
        return self.request("HEAD", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def OPTIONS(self, url, headers=None, query_params=None, post_params=None,
                body=None, _preload_content=True, _request_timeout=None):
        return self.request("OPTIONS", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def DELETE(self, url, headers=None, query_params=None, body=None,
               _preload_content=True, _request_timeout=None):
        return self.request("DELETE", url,
                            headers=headers,
                            query_params=query_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def POST(self, url, headers=None, query_params=None, post_params=None,
             body=None, _preload_content=True, _request_timeout=None):
        return self.request("POST", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PUT(self, url, headers=None, query_params=None, post_params=None,
            body=None, _preload_content=True, _request_timeout=None):
        return self.request("PUT", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PATCH(self, url, headers=None, query_params=None, post_params=None,
              body=None, _preload_content=True, _request_timeout=None):
        return self.request("PATCH", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)


class ApiException(Exception):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(
                self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        logger.error(error_message)
        return error_message


# coding: utf-8

"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import re  # noqa: F401

import six


class ApiResponse:
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """ # noqa: E501
    swagger_types = {
        'value': 'dict(object, object)',
    }

    attribute_map = {
        'value': 'value'
    }

    def __init__(self, value):
        self.value = value

    def set(self, new):
        self.value = new

    def get(self):
        return self.value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference import DataProtectionSiteReference  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceReplicationStatus import ProtectedResourceReplicationStatus  # noqa: F401,E501

class ReplicationState(object):

    """Replication related information about the protected resource.

    :param protection_policy_reference: (:attr:`protection_policy_reference`) The external identifier of the protection policy associated with the protected resource.
    :type protection_policy_reference: 
    :param recovery_point_objective: (:attr:`recovery_point_objective`) The recovery point objective of the schedule in seconds.
    :type recovery_point_objective: 
    :param replication_status: (:attr:`replication_status`) 
    :type replication_status: 
    :param target_site_reference: (:attr:`target_site_reference`) 
    :type target_site_reference: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'protection_policy_reference': 'str',
        'recovery_point_objective': 'int',
        'replication_status': 'dataprotection.v4.config.ProtectedResourceReplicationStatus',
        'target_site_reference': 'dataprotection.v4.config.DataProtectionSiteReference',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'protection_policy_reference': 'protectionPolicyReference',
        'recovery_point_objective': 'recoveryPointObjective',
        'replication_status': 'replicationStatus',
        'target_site_reference': 'targetSiteReference',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, protection_policy_reference=None, recovery_point_objective=None, replication_status=None, target_site_reference=None, *args, **kwargs):  # noqa: E501
        self.__protection_policy_reference = None
        self.__recovery_point_objective = None
        self.__replication_status = None
        self.__target_site_reference = None
        self.discriminator = None
        if protection_policy_reference is not None:
            self.__protection_policy_reference = protection_policy_reference
        if recovery_point_objective is not None:
            self.__recovery_point_objective = recovery_point_objective
        if replication_status is not None:
            self.__replication_status = replication_status
        if target_site_reference is not None:
            self.__target_site_reference = target_site_reference
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.ReplicationState'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.ReplicationState'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fqObjectType": self._initialize_fq_object_type()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def protection_policy_reference(self):
        """
        The external identifier of the protection policy associated with the protected resource.

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__protection_policy_reference

    @protection_policy_reference.setter
    def protection_policy_reference(self, protection_policy_reference):
        if protection_policy_reference is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', protection_policy_reference):  # noqa: E501
            raise ValueError(r"Invalid value for `protection_policy_reference`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__protection_policy_reference = protection_policy_reference

    @property
    def recovery_point_objective(self):
        """
        The recovery point objective of the schedule in seconds.

        :type:

                :class:`~int`
        """  # noqa: E501
        return self.__recovery_point_objective

    @recovery_point_objective.setter
    def recovery_point_objective(self, recovery_point_objective):

        self.__recovery_point_objective = recovery_point_objective

    @property
    def replication_status(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceReplicationStatus`
        """  # noqa: E501
        return self.__replication_status

    @replication_status.setter
    def replication_status(self, replication_status):

        self.__replication_status = replication_status

    @property
    def target_site_reference(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference`
        """  # noqa: E501
        return self.__target_site_reference

    @target_site_reference.setter
    def target_site_reference(self, target_site_reference):

        self.__target_site_reference = target_site_reference

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ReplicationState, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReplicationState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8

# flake8: noqa

"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

# import models into model package
from ntnx_dataprotection_py_client.models.OneOfcommon.v1.config.KVPairvalue import KVPairvalue
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ChangedRegionsListApiResponsedata import ChangedRegionsListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ConsistencyGroupApiResponsedata import ConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ConsistencyGroupListApiResponsedata import ConsistencyGroupListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ConsistencyGroupMigrateApiResponsedata import ConsistencyGroupMigrateApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.CreateConsistencyGroupRecoveryPointApiResponsedata import CreateConsistencyGroupRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.CreateRecoveryPointApiResponsedata import CreateRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DeleteConsistencyGroupApiResponsedata import DeleteConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DeleteRecoveryPointApiResponsedata import DeleteRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DiskRecoveryPointApiResponsedata import DiskRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DiskRecoveryPointListApiResponsedata import DiskRecoveryPointListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourceApiResponsedata import ProtectedResourceApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourcePromoteApiResponsedata import ProtectedResourcePromoteApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourceRestoreApiResponsedata import ProtectedResourceRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointApiResponsedata import RecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointListApiResponsedata import RecoveryPointListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointReplicateApiResponsedata import RecoveryPointReplicateApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRestoreApiResponsedata import RecoveryPointRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.SyncedVolumeGroupByIdApiResponsedata import SyncedVolumeGroupByIdApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.SynchronousReplicaPromoteApiResponsedata import SynchronousReplicaPromoteApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponsedata import UpdateRecoveryPointExpirationTimeApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VMRecoveryPointApiResponsedata import VMRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VMRecoveryPointListApiResponsedata import VMRecoveryPointListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ValidateRestoreVmRecoveryPointApiResponsedata import ValidateRestoreVmRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VmRecoveryPointRestoreApiResponsedata import VmRecoveryPointRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VolumeGroupRecoveryPointApiResponsedata import VolumeGroupRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VolumeGroupRecoveryPointListApiResponsedata import VolumeGroupRecoveryPointListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VolumeGroupRecoveryPointRestoreApiResponsedata import VolumeGroupRecoveryPointRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.WitnessApiResponsedata import WitnessApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.error.ErrorResponseerror import ErrorResponseerror
from ntnx_dataprotection_py_client.models.common.v1.config.Flag import Flag
from ntnx_dataprotection_py_client.models.common.v1.config.IPv4Address import IPv4Address
from ntnx_dataprotection_py_client.models.common.v1.config.KVPair import KVPair
from ntnx_dataprotection_py_client.models.common.v1.config.Message import Message
from ntnx_dataprotection_py_client.models.common.v1.config.MessageSeverity import MessageSeverity
from ntnx_dataprotection_py_client.models.common.v1.config.TenantAwareModel import TenantAwareModel
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink
from ntnx_dataprotection_py_client.models.common.v1.response.ApiResponseMetadata import ApiResponseMetadata
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseRecoveryPoint import BaseRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointStatus import RecoveryPointStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointType import RecoveryPointType
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.VendorSpecificProperty import VendorSpecificProperty
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.AhvVmOverrideSpec import AhvVmOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Category import Category
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ChangedRegions import ChangedRegions
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ChangedRegionsListApiResponse import ChangedRegionsListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ClusterReference import ClusterReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroup import ConsistencyGroup
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupApiResponse import ConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupListApiResponse import ConsistencyGroupListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember import ConsistencyGroupMember
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMemberType import ConsistencyGroupMemberType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMigrateApiResponse import ConsistencyGroupMigrateApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMigrationSpec import ConsistencyGroupMigrationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupProjection import ConsistencyGroupProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupRecoveryPointSpec import ConsistencyGroupRecoveryPointSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateConsistencyGroupRecoveryPointApiResponse import CreateConsistencyGroupRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateRecoveryPointApiResponse import CreateRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionInfo import DataProtectionInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference import DataProtectionSiteReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteConsistencyGroupApiResponse import DeleteConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteRecoveryPointApiResponse import DeleteRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DisasterRecoveryLocation import DisasterRecoveryLocation
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Disk import Disk
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DiskRecoveryPoint import DiskRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DiskRecoveryPointApiResponse import DiskRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DiskRecoveryPointListApiResponse import DiskRecoveryPointListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.EsxiVmOverrideSpec import EsxiVmOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HardwareArchitecture import HardwareArchitecture
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostReference import HostReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostType import HostType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HypervisorType import HypervisorType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.IpAddress import IpAddress
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.LocationReference import LocationReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.PowerState import PowerState
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResource import ProtectedResource
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceApiResponse import ProtectedResourceApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceEntityType import ProtectedResourceEntityType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourcePromoteApiResponse import ProtectedResourcePromoteApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceReplicationStatus import ProtectedResourceReplicationStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreApiResponse import ProtectedResourceRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreSpec import ProtectedResourceRestoreSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryInfo import RecoveryInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPoint import RecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointApiResponse import RecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointListApiResponse import RecoveryPointListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicateApiResponse import RecoveryPointReplicateApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicationSpec import RecoveryPointReplicationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestorationSpec import RecoveryPointRestorationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestoreApiResponse import RecoveryPointRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Regions import Regions
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ReplicationState import ReplicationState
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RestorableTimeRange import RestorableTimeRange
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SetExpirationTimeSpec import SetExpirationTimeSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteReference import SiteReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Subnet import Subnet
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SyncedVolumeGroupByIdApiResponse import SyncedVolumeGroupByIdApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SynchronousReplicaPromoteApiResponse import SynchronousReplicaPromoteApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponse import UpdateRecoveryPointExpirationTimeApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VMRecoveryPoint import VMRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VMRecoveryPointApiResponse import VMRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VMRecoveryPointListApiResponse import VMRecoveryPointListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ValidateRecoveryPointResult import ValidateRecoveryPointResult
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ValidateRestoreVmRecoveryPointApiResponse import ValidateRestoreVmRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ValidationSeverity import ValidationSeverity
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Vm import Vm
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPointRestorationSpec import VmRecoveryPointRestorationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPointRestoreApiResponse import VmRecoveryPointRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPointRestoreOverride import VmRecoveryPointRestoreOverride
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmSubRecoveryPoint import VmSubRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmSubRecoveryPointProjection import VmSubRecoveryPointProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroup import VolumeGroup
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupOverrideSpec import VolumeGroupOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPoint import VolumeGroupRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointApiResponse import VolumeGroupRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointListApiResponse import VolumeGroupRecoveryPointListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointRestorationSpec import VolumeGroupRecoveryPointRestorationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointRestoreApiResponse import VolumeGroupRecoveryPointRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointRestoreOverride import VolumeGroupRecoveryPointRestoreOverride
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSubRecoveryPoint import VolumeGroupSubRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSubRecoveryPointProjection import VolumeGroupSubRecoveryPointProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSyncContext import VolumeGroupSyncContext
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VpcReference import VpcReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Witness import Witness
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.WitnessApiResponse import WitnessApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.WitnessAvailabilityStatus import WitnessAvailabilityStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.AppMessage import AppMessage
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.ErrorResponse import ErrorResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.SchemaValidationError import SchemaValidationError
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.SchemaValidationErrorMessage import SchemaValidationErrorMessage
from ntnx_dataprotection_py_client.models.prism.v4.config.TaskReference import TaskReference
from ntnx_dataprotection_py_client.models.storage.v4.config.Task import Task
from ntnx_dataprotection_py_client.api_response import ApiResponse



# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmSubRecoveryPoint import VmSubRecoveryPoint  # noqa: F401,E501

class VmSubRecoveryPointProjection(VmSubRecoveryPoint):

    """

    :param vm_recovery_point_id: (:attr:`vm_recovery_point_id`) The external identifier that can be used to retrieve the VM Recovery point using its URL.
    :type vm_recovery_point_id: 
    :param consistency_group_ext_id: (:attr:`consistency_group_ext_id`) External identifier of the Consistency group which the entity was part of at the time of Recovery point creation.
    :type consistency_group_ext_id: 
    :param location_agnostic_id: (:attr:`location_agnostic_id`) Location agnostic identifier of the Recovery point. This identifier is used to identify the same instances of a Recovery point across different sites.
    :type location_agnostic_id: 
    :param vm_ext_id: (:attr:`vm_ext_id`) VM external identifier which is captured as part of this Recovery point.
    :type vm_ext_id: 
    :param vm_categories: (:attr:`vm_categories`) Category key-value pairs associated with the VM at the time of Recovery point creation. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' will be represented as 'dept/hr'.
    :type vm_categories: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'vm_recovery_point_id': 'str',
        'consistency_group_ext_id': 'str',
        'location_agnostic_id': 'str',
        'vm_ext_id': 'str',
        'vm_categories': 'list[str]',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'vm_recovery_point_id': 'vmRecoveryPointId',
        'consistency_group_ext_id': 'consistencyGroupExtId',
        'location_agnostic_id': 'locationAgnosticId',
        'vm_ext_id': 'vmExtId',
        'vm_categories': 'vmCategories',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, vm_recovery_point_id=None, consistency_group_ext_id=None, location_agnostic_id=None, vm_ext_id=None, vm_categories=None, *args, **kwargs):  # noqa: E501
        VmSubRecoveryPoint.__init__(self, vm_recovery_point_id, consistency_group_ext_id, location_agnostic_id, vm_ext_id, vm_categories, *args, **kwargs)
        self.discriminator = None

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.VmSubRecoveryPointProjection'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.VmSubRecoveryPointProjection'


    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VmSubRecoveryPointProjection, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VmSubRecoveryPointProjection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HardwareArchitecture import HardwareArchitecture  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HypervisorType import HypervisorType  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.PowerState import PowerState  # noqa: F401,E501

class Vm(object):

    """The configuration of the VM captured by the Recovery point.

    :param vm_ext_id: (:attr:`vm_ext_id`) VM external identifier which is captured as part of this Recovery point.
    :type vm_ext_id: 
    :param name: (:attr:`name`) The name of the VM that is captured as part of this Recovery point.
    :type name: 
    :param num_vcpus: (:attr:`num_vcpus`) Number of vCPUs.
    :type num_vcpus: 
    :param cores_per_vcpu: (:attr:`cores_per_vcpu`) Number of cores per vCPU.
    :type cores_per_vcpu: 
    :param vm_num_threads_per_core: (:attr:`vm_num_threads_per_core`) Docref(vmNumThreadsPerCoreDesc)
    :type vm_num_threads_per_core: 
    :param memory_size_bytes: (:attr:`memory_size_bytes`) Memory size in bytes.
    :type memory_size_bytes: 
    :param hypervisor_type: (:attr:`hypervisor_type`) 
    :type hypervisor_type: 
    :param power_state: (:attr:`power_state`) 
    :type power_state: 
    :param hardware_architecture: (:attr:`hardware_architecture`) 
    :type hardware_architecture: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'vm_ext_id': 'str',
        'name': 'str',
        'num_vcpus': 'int',
        'cores_per_vcpu': 'int',
        'vm_num_threads_per_core': 'int',
        'memory_size_bytes': 'int',
        'hypervisor_type': 'dataprotection.v4.config.HypervisorType',
        'power_state': 'dataprotection.v4.config.PowerState',
        'hardware_architecture': 'dataprotection.v4.config.HardwareArchitecture',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'vm_ext_id': 'vmExtId',
        'name': 'name',
        'num_vcpus': 'numVcpus',
        'cores_per_vcpu': 'coresPerVcpu',
        'vm_num_threads_per_core': 'vmNumThreadsPerCore',
        'memory_size_bytes': 'memorySizeBytes',
        'hypervisor_type': 'hypervisorType',
        'power_state': 'powerState',
        'hardware_architecture': 'hardwareArchitecture',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, vm_ext_id=None, name=None, num_vcpus=None, cores_per_vcpu=None, vm_num_threads_per_core=None, memory_size_bytes=None, hypervisor_type=None, power_state=None, hardware_architecture=None, *args, **kwargs):  # noqa: E501
        self.__vm_ext_id = None
        self.__name = None
        self.__num_vcpus = None
        self.__cores_per_vcpu = None
        self.__vm_num_threads_per_core = None
        self.__memory_size_bytes = None
        self.__hypervisor_type = None
        self.__power_state = None
        self.__hardware_architecture = None
        self.discriminator = None
        if vm_ext_id is not None:
            self.__vm_ext_id = vm_ext_id
        if name is not None:
            self.__name = name
        if num_vcpus is not None:
            self.__num_vcpus = num_vcpus
        if cores_per_vcpu is not None:
            self.__cores_per_vcpu = cores_per_vcpu
        if vm_num_threads_per_core is not None:
            self.__vm_num_threads_per_core = vm_num_threads_per_core
        if memory_size_bytes is not None:
            self.__memory_size_bytes = memory_size_bytes
        if hypervisor_type is not None:
            self.__hypervisor_type = hypervisor_type
        if power_state is not None:
            self.__power_state = power_state
        if hardware_architecture is not None:
            self.__hardware_architecture = hardware_architecture
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.Vm'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.Vm'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fqObjectType": self._initialize_fq_object_type()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def vm_ext_id(self):
        """
        VM external identifier which is captured as part of this Recovery point.

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__vm_ext_id

    @vm_ext_id.setter
    def vm_ext_id(self, vm_ext_id):
        if vm_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', vm_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `vm_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__vm_ext_id = vm_ext_id

    @property
    def name(self):
        """
        The name of the VM that is captured as part of this Recovery point.

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):

        self.__name = name

    @property
    def num_vcpus(self):
        """
        Number of vCPUs.

        :type:

                :class:`~int`
        """  # noqa: E501
        return self.__num_vcpus

    @num_vcpus.setter
    def num_vcpus(self, num_vcpus):

        self.__num_vcpus = num_vcpus

    @property
    def cores_per_vcpu(self):
        """
        Number of cores per vCPU.

        :type:

                :class:`~int`
        """  # noqa: E501
        return self.__cores_per_vcpu

    @cores_per_vcpu.setter
    def cores_per_vcpu(self, cores_per_vcpu):

        self.__cores_per_vcpu = cores_per_vcpu

    @property
    def vm_num_threads_per_core(self):
        """
        Docref(vmNumThreadsPerCoreDesc)

        :type:

                :class:`~int`
        """  # noqa: E501
        return self.__vm_num_threads_per_core

    @vm_num_threads_per_core.setter
    def vm_num_threads_per_core(self, vm_num_threads_per_core):

        self.__vm_num_threads_per_core = vm_num_threads_per_core

    @property
    def memory_size_bytes(self):
        """
        Memory size in bytes.

        :type:

                :class:`~int`
        """  # noqa: E501
        return self.__memory_size_bytes

    @memory_size_bytes.setter
    def memory_size_bytes(self, memory_size_bytes):

        self.__memory_size_bytes = memory_size_bytes

    @property
    def hypervisor_type(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.HypervisorType`
        """  # noqa: E501
        return self.__hypervisor_type

    @hypervisor_type.setter
    def hypervisor_type(self, hypervisor_type):

        self.__hypervisor_type = hypervisor_type

    @property
    def power_state(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.PowerState`
        """  # noqa: E501
        return self.__power_state

    @power_state.setter
    def power_state(self, power_state):

        self.__power_state = power_state

    @property
    def hardware_architecture(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.HardwareArchitecture`
        """  # noqa: E501
        return self.__hardware_architecture

    @hardware_architecture.setter
    def hardware_architecture(self, hardware_architecture):

        self.__hardware_architecture = hardware_architecture

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(Vm, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Vm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six

class RecoveryPointListApiResponsedata(object):

    """


    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
    }

    attribute_map = {
    }

    discriminator_value_class_map = {
        'EMPTY_LIST': 'list[str]',
        'EMPTY_MAP': 'dict(str, object)',
        'List<dataprotection.v4.config.RecoveryPoint>': 'list[dataprotection.v4.config.RecoveryPoint]',
        'dataprotection.v4.error.ErrorResponse': 'dataprotection.v4.error.ErrorResponse'
    }

    ONE_OF_ITEM_DISCRIMINATOR_NAME = '$dataItemDiscriminator'


    def __init__(self, *args, **kwargs):  # noqa: E501
        self.discriminator = None
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'OneOfdataprotection.v4.config.RecoveryPointListApiResponsedata'

    def _initialize_fq_object_type(self):
        return ''

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fqObjectType": self._initialize_fq_object_type()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    def get_real_child_model(self, discriminator):
        """Returns the real base class specified by the discriminator"""
        if discriminator is not None and discriminator in self.discriminator_value_class_map:
            return self.discriminator_value_class_map.get(discriminator)
        return None

    @staticmethod
    def get_discriminator_from_object(value):
        """Returns the discriminator for the provided object.
        """
        if not value:
            disc = 'list[str]'
        elif hasattr(value, "_object_type"):
            disc = value.get_object_type()
        elif type(value) == list:
            if hasattr(value[0], "_object_type"):
                datatype = value[0].get_object_type()
            else:
                datatype = type(value[0]).__name__
            disc = 'list[' + datatype + ']'
        elif type(value) == dict:
            if hasattr(next(iter(value.values())), "_object_type"):
                datatype = next(iter(value.values())).get_object_type()
            else:
                datatype = type(next(iter(value.values()))).__name__
            disc = 'dict(str, ' + datatype + ')'
        else:
            disc = type(value).__name__
        if disc in RecoveryPointListApiResponsedata.discriminator_value_class_map.values():
            return list(RecoveryPointListApiResponsedata.discriminator_value_class_map.keys())[list(RecoveryPointListApiResponsedata.discriminator_value_class_map.values()).index(disc)]
        return None


    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(RecoveryPointListApiResponsedata, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecoveryPointListApiResponsedata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseRecoveryPoint import BaseRecoveryPoint  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointStatus import RecoveryPointStatus  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointType import RecoveryPointType  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.VendorSpecificProperty import VendorSpecificProperty  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Disk import Disk  # noqa: F401,E501

class DiskRecoveryPoint(BaseRecoveryPoint):

    """A model that represents the disk Recovery point properties.

    :param disk: (:attr:`disk`) 
    :type disk: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'disk': 'dataprotection.v4.config.Disk',
        'location_agnostic_id': 'str',
        'name': 'str',
        'creation_time': 'datetime',
        'expiration_time': 'datetime',
        'status': 'dataprotection.v4.common.RecoveryPointStatus',
        'recovery_point_type': 'dataprotection.v4.common.RecoveryPointType',
        'vendor_specific_properties': 'list[dataprotection.v4.common.VendorSpecificProperty]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'disk': 'disk',
        'location_agnostic_id': 'locationAgnosticId',
        'name': 'name',
        'creation_time': 'creationTime',
        'expiration_time': 'expirationTime',
        'status': 'status',
        'recovery_point_type': 'recoveryPointType',
        'vendor_specific_properties': 'vendorSpecificProperties',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, disk=None, location_agnostic_id=None, name=None, creation_time=None, expiration_time=None, status=None, recovery_point_type=None, vendor_specific_properties=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        BaseRecoveryPoint.__init__(self, location_agnostic_id, name, creation_time, expiration_time, status, recovery_point_type, vendor_specific_properties, ext_id, links, tenant_id, *args, **kwargs)
        self.__disk = None
        self.discriminator = None
        if disk is not None:
            self.__disk = disk

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.DiskRecoveryPoint'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.DiskRecoveryPoint'


    @property
    def disk(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.Disk`
        """  # noqa: E501
        return self.__disk

    @disk.setter
    def disk(self, disk):

        self.__disk = disk

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(DiskRecoveryPoint, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DiskRecoveryPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostReference import HostReference  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.WitnessAvailabilityStatus import WitnessAvailabilityStatus  # noqa: F401,E501

class Witness(ExternalizableAbstractModel):

    """A model that represents the details of a Witness site.

    :param name: (:attr:`name`) Name of the Witness site.
    :type name: 
    :param host_references: (:attr:`host_references`) List of host references of the Witness.
    :type host_references: 
    :param ip_addresses: (:attr:`ip_addresses`) List of IP addresses to be assigned to the Virtual Machine.
    :type ip_addresses: 
    :param status: (:attr:`status`) 
    :type status: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'host_references': 'list[dataprotection.v4.config.HostReference]',
        'ip_addresses': 'list[str]',
        'status': 'dataprotection.v4.config.WitnessAvailabilityStatus',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'host_references': 'hostReferences',
        'ip_addresses': 'ipAddresses',
        'status': 'status',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, host_references=None, ip_addresses=None, status=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__name = None
        self.__host_references = None
        self.__ip_addresses = None
        self.__status = None
        self.discriminator = None
        if name is not None:
            self.__name = name
        if host_references is not None:
            self.__host_references = host_references
        if ip_addresses is not None:
            self.__ip_addresses = ip_addresses
        if status is not None:
            self.__status = status

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.Witness'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.Witness'


    @property
    def name(self):
        """
        Name of the Witness site.

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):

        self.__name = name

    @property
    def host_references(self):
        """
        List of host references of the Witness.

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostReference` ]
        """  # noqa: E501
        return self.__host_references

    @host_references.setter
    def host_references(self, host_references):

        self.__host_references = host_references

    @property
    def ip_addresses(self):
        """
        List of IP addresses to be assigned to the Virtual Machine.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__ip_addresses

    @ip_addresses.setter
    def ip_addresses(self, ip_addresses):

        self.__ip_addresses = ip_addresses

    @property
    def status(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.WitnessAvailabilityStatus`
        """  # noqa: E501
        return self.__status

    @status.setter
    def status(self, status):

        self.__status = status

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(Witness, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Witness):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseRecoveryPoint import BaseRecoveryPoint  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointStatus import RecoveryPointStatus  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointType import RecoveryPointType  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.VendorSpecificProperty import VendorSpecificProperty  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.LocationReference import LocationReference  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmSubRecoveryPoint import VmSubRecoveryPoint  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSubRecoveryPoint import VolumeGroupSubRecoveryPoint  # noqa: F401,E501

class RecoveryPoint(BaseRecoveryPoint):

    """Details about the Recovery point along with all the captured VM and volume group Recovery point(s).

    :param owner_ext_id: (:attr:`owner_ext_id`) A read only field inserted into Recovery point at the time of Recovery point creation, indicating the external identifier of the user who created this Recovery point.
    :type owner_ext_id: 
    :param location_references: (:attr:`location_references`) List of location references where the VM or volume group Recovery points are a part of the specified Recovery point.
    :type location_references: 
    :param vm_reference_list: (:attr:`vm_reference_list`) List of VM external identifiers that are intended to be captured as part of the Recovery point.
    :type vm_reference_list: 
    :param volume_group_reference_list: (:attr:`volume_group_reference_list`) List of volume group external identifiers that are intended to be captured as part of the Recovery point.
    :type volume_group_reference_list: 
    :param vm_recovery_points: (:attr:`vm_recovery_points`) List of VM Recovery points that are a part of the specified top-level Recovery point.
    :type vm_recovery_points: 
    :param volume_group_recovery_points: (:attr:`volume_group_recovery_points`) List of volume group Recovery points that are a part of the specified top-level Recovery point.
    :type volume_group_recovery_points: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'owner_ext_id': 'str',
        'location_references': 'list[dataprotection.v4.config.LocationReference]',
        'vm_reference_list': 'list[str]',
        'volume_group_reference_list': 'list[str]',
        'vm_recovery_points': 'list[dataprotection.v4.config.VmSubRecoveryPoint]',
        'volume_group_recovery_points': 'list[dataprotection.v4.config.VolumeGroupSubRecoveryPoint]',
        'location_agnostic_id': 'str',
        'name': 'str',
        'creation_time': 'datetime',
        'expiration_time': 'datetime',
        'status': 'dataprotection.v4.common.RecoveryPointStatus',
        'recovery_point_type': 'dataprotection.v4.common.RecoveryPointType',
        'vendor_specific_properties': 'list[dataprotection.v4.common.VendorSpecificProperty]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'owner_ext_id': 'ownerExtId',
        'location_references': 'locationReferences',
        'vm_reference_list': 'vmReferenceList',
        'volume_group_reference_list': 'volumeGroupReferenceList',
        'vm_recovery_points': 'vmRecoveryPoints',
        'volume_group_recovery_points': 'volumeGroupRecoveryPoints',
        'location_agnostic_id': 'locationAgnosticId',
        'name': 'name',
        'creation_time': 'creationTime',
        'expiration_time': 'expirationTime',
        'status': 'status',
        'recovery_point_type': 'recoveryPointType',
        'vendor_specific_properties': 'vendorSpecificProperties',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, owner_ext_id=None, location_references=None, vm_reference_list=None, volume_group_reference_list=None, vm_recovery_points=None, volume_group_recovery_points=None, location_agnostic_id=None, name=None, creation_time=None, expiration_time=None, status=None, recovery_point_type=None, vendor_specific_properties=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        BaseRecoveryPoint.__init__(self, location_agnostic_id, name, creation_time, expiration_time, status, recovery_point_type, vendor_specific_properties, ext_id, links, tenant_id, *args, **kwargs)
        self.__owner_ext_id = None
        self.__location_references = None
        self.__vm_reference_list = None
        self.__volume_group_reference_list = None
        self.__vm_recovery_points = None
        self.__volume_group_recovery_points = None
        self.discriminator = None
        if owner_ext_id is not None:
            self.__owner_ext_id = owner_ext_id
        if location_references is not None:
            self.__location_references = location_references
        if vm_reference_list is not None:
            self.__vm_reference_list = vm_reference_list
        if volume_group_reference_list is not None:
            self.__volume_group_reference_list = volume_group_reference_list
        if vm_recovery_points is not None:
            self.__vm_recovery_points = vm_recovery_points
        if volume_group_recovery_points is not None:
            self.__volume_group_recovery_points = volume_group_recovery_points

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.RecoveryPoint'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.RecoveryPoint'


    @property
    def owner_ext_id(self):
        """
        A read only field inserted into Recovery point at the time of Recovery point creation, indicating the external identifier of the user who created this Recovery point.

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__owner_ext_id

    @owner_ext_id.setter
    def owner_ext_id(self, owner_ext_id):
        if owner_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', owner_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `owner_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__owner_ext_id = owner_ext_id

    @property
    def location_references(self):
        """
        List of location references where the VM or volume group Recovery points are a part of the specified Recovery point.

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.LocationReference` ]
        """  # noqa: E501
        return self.__location_references

    @location_references.setter
    def location_references(self, location_references):

        self.__location_references = location_references

    @property
    def vm_reference_list(self):
        """
        List of VM external identifiers that are intended to be captured as part of the Recovery point.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__vm_reference_list

    @vm_reference_list.setter
    def vm_reference_list(self, vm_reference_list):

        self.__vm_reference_list = vm_reference_list

    @property
    def volume_group_reference_list(self):
        """
        List of volume group external identifiers that are intended to be captured as part of the Recovery point.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__volume_group_reference_list

    @volume_group_reference_list.setter
    def volume_group_reference_list(self, volume_group_reference_list):

        self.__volume_group_reference_list = volume_group_reference_list

    @property
    def vm_recovery_points(self):
        """
        List of VM Recovery points that are a part of the specified top-level Recovery point.

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmSubRecoveryPoint` ]
        """  # noqa: E501
        return self.__vm_recovery_points

    @vm_recovery_points.setter
    def vm_recovery_points(self, vm_recovery_points):

        self.__vm_recovery_points = vm_recovery_points

    @property
    def volume_group_recovery_points(self):
        """
        List of volume group Recovery points that are a part of the specified top-level Recovery point.

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSubRecoveryPoint` ]
        """  # noqa: E501
        return self.__volume_group_recovery_points

    @volume_group_recovery_points.setter
    def volume_group_recovery_points(self, volume_group_recovery_points):

        self.__volume_group_recovery_points = volume_group_recovery_points

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(RecoveryPoint, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecoveryPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ntnx_dataprotection_py_client.api_client import ApiClient


class ConsistencyGroupApi(object):
    """IGNORE:
    NOTE: A placeholder for class level description
    IGNORE
    """  # noqa: E501

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()

        self.api_client = api_client
        self.__headers_to_skip = { 'authorization', 'cookie', 'ntnx-request-id', 'host', 'user-agent' }

    def create_consistency_group(self, body, **kwargs):  # noqa: E501
        """Create a Consistency group.

        >>> response = api.create_consistency_group(body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.create_consistency_group(body, async_req=True)
        >>> result = thread.get()

        :param body: There are many scenarios where the state of an application must be captured as an aggregate of the internal state of a set of related entities at some point in time. The Consistency group is a collection of all the entities whose snapshot represents the application state at that point in time
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroup`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_consistency_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        # Authentication setting
        auth_settings = ['basicAuthScheme']  # noqa: E501

        if kwargs.get('async_req'):
            return self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups', 'POST',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.ConsistencyGroupApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
        else:
            (data) = self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups', 'POST',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.ConsistencyGroupApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
            return data

    def delete_consistency_group(self, extId, **kwargs):  # noqa: E501
        """Delete a Consistency group.

        >>> response = api.delete_consistency_group(extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.delete_consistency_group(extId, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the Consistency group.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteConsistencyGroupApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `delete_consistency_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        body_params = None

        # Authentication setting
        auth_settings = ['basicAuthScheme']  # noqa: E501

        if kwargs.get('async_req'):
            return self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups/{extId}', 'DELETE',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.DeleteConsistencyGroupApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
        else:
            (data) = self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups/{extId}', 'DELETE',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.DeleteConsistencyGroupApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
            return data

    def get_consistency_group(self, extId, **kwargs):  # noqa: E501
        """Get a Consistency group.

        >>> response = api.get_consistency_group(extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.get_consistency_group(extId, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the Consistency group.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `get_consistency_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        body_params = None

        # Authentication setting
        auth_settings = ['basicAuthScheme']  # noqa: E501

        if kwargs.get('async_req'):
            return self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups/{extId}', 'GET',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.ConsistencyGroupApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
        else:
            (data) = self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups/{extId}', 'GET',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.ConsistencyGroupApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
            return data

    def get_consistency_groups(self, vmList=None, volumeGroupList=None, _page=None, _limit=None, _filter=None, _orderby=None, _select=None, **kwargs):  # noqa: E501
        """List Consistency groups.

        >>> response = api.get_consistency_groups((optional) vmList, (optional) volumeGroupList, (optional) _page, (optional) _limit, (optional) _filter, (optional) _orderby, (optional) _select)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.get_consistency_groups(async_req=True)
        >>> result = thread.get()

        :param vmList: List of VM external identifiers. This endpoint will return the list of Consistency groups that are part of the provided VM external identifiers list.
        :type vmList:
            list[:class:`list[str]`]
        :param volumeGroupList: List of volume group external identifiers. This endpoint will return the list of Consistency groups that are part of the provided volume group external identifiers list.
        :type volumeGroupList:
            list[:class:`list[str]`]
        :param _page: A URL query parameter that specifies the page number of the result set.  Must be a positive integer between 0 and the maximum number of pages that are available for that resource. Any number out of this range will lead to no results being returned. 
        :type _page:
            :class:`int`
        :param _limit: A URL query parameter that specifies the total number of records returned in the result set.  Must be a positive integer between 1 and 100. Any number out of this range will lead to a validation error. If the limit is not provided a default value of 50 records will be returned in the result set. 
        :type _limit:
            :class:`int`
        :param _filter: A URL query parameter that allows clients to filter a collection of resources. The expression specified with $filter is evaluated for each resource in the collection, and only items where the expression evaluates to true are included in the response. Expression specified with the $filter must conform to the OData V4.01 URL conventions. For example, filter '$filter=name eq 'karbon-ntnx-1.0' would filter result on cluster name karbon-ntnx1.0, filter '$filter=startswith(name, 'C')' would filter on cluster name starting with C. The filter can be applied on the following fields: - extId - members/entityId - members/extId - name - ownerExtId 
        :type _filter:
            :class:`str`
        :param _orderby: A URL query parameter that allows clients to specify the sort criteria for the returned list of objects. Resources can be sorted in ascending order using asc or descending order using desc. If asc or desc are not specified the resources will be sorted in ascending order by default. For example, '$orderby=templateName desc' would get all templates sorted by templateName in desc order. The orderby can be applied to the following fields: - name 
        :type _orderby:
            :class:`str`
        :param _select: A URL query parameter that allows clients to request a specific set of properties for each entity or complex type. Expression specified with the $select must conform to the OData V4.01 URL conventions. If a $select expression consists of a single select item that is an asterisk (i.e. *), then all properties on the matching resource will be returned. - extId - name - ownerExtId 
        :type _select:
            :class:`str`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupListApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'vmList' in params and params['vmList'] is not None:
            query_params.append(('vmList', params['vmList']))  # noqa: E501
            collection_formats['vmList'] = 'csv'  # noqa: E501
        if 'volumeGroupList' in params and params['volumeGroupList'] is not None:
            query_params.append(('volumeGroupList', params['volumeGroupList']))  # noqa: E501
            collection_formats['volumeGroupList'] = 'csv'  # noqa: E501
        if '_page' in params and params['_page'] is not None:
            query_params.append(('$page', params['_page']))  # noqa: E501
        if '_limit' in params and params['_limit'] is not None:
            query_params.append(('$limit', params['_limit']))  # noqa: E501
        if '_filter' in params and params['_filter'] is not None:
            query_params.append(('$filter', params['_filter']))  # noqa: E501
        if '_orderby' in params and params['_orderby'] is not None:
            query_params.append(('$orderby', params['_orderby']))  # noqa: E501
        if '_select' in params and params['_select'] is not None:
            query_params.append(('$select', params['_select']))  # noqa: E501

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['vmList', 'volumeGroupList', '_page', '_limit', '_filter', '_orderby', '_select'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        body_params = None

        # Authentication setting
        auth_settings = ['basicAuthScheme']  # noqa: E501

        if kwargs.get('async_req'):
            return self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups', 'GET',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.ConsistencyGroupListApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
        else:
            (data) = self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups', 'GET',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.ConsistencyGroupListApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
            return data

    def update_consistency_group(self, extId, body, **kwargs):  # noqa: E501
        """Update a Consistency group.

        >>> response = api.update_consistency_group(extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.update_consistency_group(extId, body, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the Consistency group.
        :type extId:
            :class:`str`, required
        :param body: Required details for updating the Consistency group.
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroup`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `update_consistency_group`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_consistency_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        # Authentication setting
        auth_settings = ['basicAuthScheme']  # noqa: E501

        if kwargs.get('async_req'):
            return self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups/{extId}', 'PUT',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.ConsistencyGroupApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
        else:
            (data) = self.api_client._call_api(
                '/api/dataprotection/v4.0.a4/config/consistency-groups/{extId}', 'PUT',
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type='dataprotection.v4.config.ConsistencyGroupApiResponse',  # noqa: E501
                auth_settings=auth_settings,
                async_req=params.get('async_req'),
                _return_http_data_only=params.get('_return_http_data_only'),
                _preload_content=params.get('_preload_content', True),
                _request_timeout=params.get('_request_timeout'),
                collection_formats=collection_formats)
            return data



# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionInfo import DataProtectionInfo  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference import DataProtectionSiteReference  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceEntityType import ProtectedResourceEntityType  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ReplicationState import ReplicationState  # noqa: F401,E501

class ProtectedResource(ExternalizableAbstractModel):

    """Once a VM or volume group is associated with some protection policy, the schedule(s) in the protection policy kick in to achieve the specified recovery point objective. A protected resource represents the data protection view of such a VM or volume group. It contains information such as the restorable time ranges on the local Prism Central and the state of replication to the targets specified in all the applied protection policies.

    :param entity_ext_id: (:attr:`entity_ext_id`) The external identifier of the VM or the volume group associated with the protected resource.
    :type entity_ext_id: 
    :param entity_type: (:attr:`entity_type`) 
    :type entity_type: 
    :param source_site_reference: (:attr:`source_site_reference`) 
    :type source_site_reference: 
    :param data_protection_info: (:attr:`data_protection_info`) The data protection details for the protected resource that are relevant to any of the clusters in the local Prism Central, like the time ranges available for recovery.
    :type data_protection_info: 
    :param replication_states: (:attr:`replication_states`) 
    :type replication_states: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'entity_ext_id': 'str',
        'entity_type': 'dataprotection.v4.config.ProtectedResourceEntityType',
        'source_site_reference': 'dataprotection.v4.config.DataProtectionSiteReference',
        'data_protection_info': 'list[dataprotection.v4.config.DataProtectionInfo]',
        'replication_states': 'list[dataprotection.v4.config.ReplicationState]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'entity_ext_id': 'entityExtId',
        'entity_type': 'entityType',
        'source_site_reference': 'sourceSiteReference',
        'data_protection_info': 'dataProtectionInfo',
        'replication_states': 'replicationStates',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, entity_ext_id=None, entity_type=None, source_site_reference=None, data_protection_info=None, replication_states=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__entity_ext_id = None
        self.__entity_type = None
        self.__source_site_reference = None
        self.__data_protection_info = None
        self.__replication_states = None
        self.discriminator = None
        if entity_ext_id is not None:
            self.__entity_ext_id = entity_ext_id
        if entity_type is not None:
            self.__entity_type = entity_type
        if source_site_reference is not None:
            self.__source_site_reference = source_site_reference
        if data_protection_info is not None:
            self.__data_protection_info = data_protection_info
        if replication_states is not None:
            self.__replication_states = replication_states

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.ProtectedResource'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.ProtectedResource'


    @property
    def entity_ext_id(self):
        """
        The external identifier of the VM or the volume group associated with the protected resource.

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__entity_ext_id

    @entity_ext_id.setter
    def entity_ext_id(self, entity_ext_id):
        if entity_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', entity_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `entity_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__entity_ext_id = entity_ext_id

    @property
    def entity_type(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceEntityType`
        """  # noqa: E501
        return self.__entity_type

    @entity_type.setter
    def entity_type(self, entity_type):

        self.__entity_type = entity_type

    @property
    def source_site_reference(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference`
        """  # noqa: E501
        return self.__source_site_reference

    @source_site_reference.setter
    def source_site_reference(self, source_site_reference):

        self.__source_site_reference = source_site_reference

    @property
    def data_protection_info(self):
        """
        The data protection details for the protected resource that are relevant to any of the clusters in the local Prism Central, like the time ranges available for recovery.

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionInfo` ]
        """  # noqa: E501
        return self.__data_protection_info

    @data_protection_info.setter
    def data_protection_info(self, data_protection_info):

        self.__data_protection_info = data_protection_info

    @property
    def replication_states(self):
        """
        

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ReplicationState` ]
        """  # noqa: E501
        return self.__replication_states

    @replication_states.setter
    def replication_states(self, replication_states):

        self.__replication_states = replication_states

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ProtectedResource, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtectedResource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember import ConsistencyGroupMember  # noqa: F401,E501

class ConsistencyGroup(ExternalizableAbstractModel):

    """There are many scenarios where the state of an application must be captured as an aggregate of the internal state of a set of related entities at some point in time. The Consistency group is a collection of all the entities whose snapshot represents the application state at that point in time

    :param name: (:attr:`name`) Name of the Consistency group.
    :type name: required
    :param owner_ext_id: (:attr:`owner_ext_id`) The external identifier of the user who created this Consistency group. This is a read-only field that is inserted into the Consistency group entity at the time of Consistency group creation.
    :type owner_ext_id: 
    :param members: (:attr:`members`) 
    :type members: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'owner_ext_id': 'str',
        'members': 'list[dataprotection.v4.config.ConsistencyGroupMember]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'owner_ext_id': 'ownerExtId',
        'members': 'members',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, owner_ext_id=None, members=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__name = None
        self.__owner_ext_id = None
        self.__members = None
        self.discriminator = None
        self.__name = name
        if owner_ext_id is not None:
            self.__owner_ext_id = owner_ext_id
        if members is not None:
            self.__members = members

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.ConsistencyGroup'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.ConsistencyGroup'


    @property
    def name(self):
        """
        Name of the Consistency group.

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 256:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `256`")  # noqa: E501

        self.__name = name

    @property
    def owner_ext_id(self):
        """
        The external identifier of the user who created this Consistency group. This is a read-only field that is inserted into the Consistency group entity at the time of Consistency group creation.

        :type:

                :class:`~str`
        """  # noqa: E501
        return self.__owner_ext_id

    @owner_ext_id.setter
    def owner_ext_id(self, owner_ext_id):
        if owner_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', owner_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `owner_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__owner_ext_id = owner_ext_id

    @property
    def members(self):
        """
        

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember` ]
        """  # noqa: E501
        return self.__members

    @members.setter
    def members(self, members):

        self.__members = members

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ConsistencyGroup, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConsistencyGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import io
import os
from setuptools import setup, find_packages  # noqa: H301

NAME = "ntnx-dataprotection-py-client"
VERSION = "4.0.1a4"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 ~= 1.26", "six ~= 1.16", "certifi == 2020.4.5.1", "python-dateutil ~= 2.8", "pysocks ~= 1.7"]

package_root_path = os.path.abspath(os.path.dirname(__file__))
readme_file_path = os.path.join(package_root_path, "README.md")
with io.open(readme_file_path, encoding="utf-8") as readme_file:
    readme = readme_file.read()

setup(
    name=NAME,
    version=VERSION,
    description="Nutanix Dataprotection Versioned APIs",
    author_email="sdk@nutanix.com",
    url="",
    keywords=["Nutanix", "v4", "SDK", "Nutanix Dataprotection Versioned APIs"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=readme,
    long_description_content_type="text/markdown",
)
